pub struct Material {
pub base_color_texture: Texture,
pub base_color_factor: Color,
pub bind_group: BindGroup,
}Expand description
A material defining the surface appearance of a mesh.
Fields
base_color_texture: Texturebase_color_factor: Colorbind_group: BindGroupImplementations
Sourceimpl Material
impl Material
Sourcepub fn new(
device: &Device,
layout: &BindGroupLayout,
texture: Texture,
base_color_factor: Color,
) -> Self
pub fn new( device: &Device, layout: &BindGroupLayout, texture: Texture, base_color_factor: Color, ) -> Self
Create a material from a texture and color factor.
Sourcepub fn default_material(
device: &Device,
queue: &Queue,
layout: &BindGroupLayout,
) -> Self
pub fn default_material( device: &Device, queue: &Queue, layout: &BindGroupLayout, ) -> Self
Create a default material (white pixel texture, white color).